Schlegel View

## 7.1 Schlegel View

In addition to the 3D view of the current structure a 2D projection (Schlegel) view can also be rendered. The two parameters involved in the calculation of this projection are accessed through Calculations–Schlegel. The parameter `Gamma`() determines the magnitude of the projection via:

The `Cutoff` value determines the points that are used for the projection. An example projection is shown in Fig. 13.

Figure 13: Schlegel options and render window.